#
# spec file for package fox16
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         lname	libFOX-1_6-0

Name:           fox16
Version:        1.6.57
Release:        4.7
Summary:        Shared Libraries for the FOX Toolkit
License:        LGPL-2.1-or-later
Group:          Development/Languages/C and C++
URL:            http://www.fox-toolkit.org/
Source0:        ftp://ftp.fox-toolkit.org/pub/fox-%{version}.tar.gz
Source1:        calculator.png
Source2:        pathfinder.png
Source3:        adie.png
Source4:        fox16-rpmlintrc
Source5:        adie.desktop
Source6:        calculator.desktop
Source7:        pathfinder.desktop
# PATCH-FIX-OPENSUSE remove date from reswrap help to support build compare
Patch1:         fox16-remove_date_from_reswrap.patch
# PATCH-FIX-UPSTREAM add closing html tag
Patch2:         fox-1.6.26-missing_html_tag.patch
BuildRequires:  cups-devel
BuildRequires:  doxygen
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xi)

%description
FOX is a C++-based library for graphical user interface development.

FOX supports modern GUI features such as drag-and-drop, tooltips, tab
books, tree lists, icons, multiple document interfaces (MDI), timers,
idle processing, automatic GUI updating, as well as OpenGL/Mesa for 3D
graphics. Subclassing of basic FOX widgets allows for easy extension
beyond the built-in widgets by application writers.

%package -n %{lname}
Summary:        Shared libraries for the FOX toolkit 1.6
Group:          System/Libraries
Provides:       fox = %{version}-%{release}
# Added O/P in 13.2
Provides:       libfox1_6 = %{version}-%{release}
Obsoletes:      libfox1_6 < %{version}

%description -n %{lname}
This package contains the shared libraries needed
by applications compiled with the FOX GUI Toolkit.

%package devel
Summary:        Development Files and Documentation for the FOX GUI Toolkit 1.6
Group:          Development/Languages/C and C++
Requires:       %{lname} = %{version}
Requires:       bzip2
Requires:       cups-devel
Requires:       cups-libs
Requires:       glibc-devel
Provides:       fox-devel = %{version}-%{release}

Requires:       expat
# lots of -l hardcoded in fox.pc without pkgconfig-level Requires tags
Requires:       libbz2-devel
Requires:       libexpat-devel
Requires:       libjpeg-devel
Requires:       libpng-devel
Requires:       libtiff-devel
Requires:       zlib-devel
Requires:       pkgconfig(fontconfig)
Requires:       pkgconfig(freetype2)
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xcursor)
Requires:       pkgconfig(xext)
Requires:       pkgconfig(xft)
Requires:       pkgconfig(xi)
Requires:       pkgconfig(xproto)
Requires:       pkgconfig(xrandr)
Requires:       pkgconfig(xrender)

%description devel
FOX is a C++-based library for graphical user interface development.

The devel package contains the files necessary to develop applications
using the FOX GUI toolkit: the header files, the reswrap resource
compiler, and manual pages.

%package doc
Summary:        Documentation for the FOX Toolkit 1.6
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
FOX is a C++-based library for graphical user interface development.

The doc subpackage contains the HTML documentation to the FOX toolkit 1.6.

%package devel-static
Summary:        Static Libraries for the FOX Toolkit 1.6
Group:          Development/Languages/C and C++
Requires:       %{name}-devel = %{version}
Provides:       %{name}-static = %{version}-%{release}
Obsoletes:      %{name}-static < 1.6.36
# skip dependency checks required by libtool .la files => skip-check-libtool-deps

%description devel-static
This package contains static libraries for developing applications
which are statically linked against the FOX libraries.

FOX is a C++-based library for graphical user interface development.

%package example-apps
Summary:        Example applications for the FOX GUI toolkit
Group:          Development/Languages/C and C++
Provides:       fox-example-apps = %{version}

%description example-apps
The example-apps package contains executables for several FOX-based
applications, including:

* Adie : Programmer's Text Editor

* calculator : Calculator Applet

* shutterbug : Screenshot Utility

* PathFinder : File Browser

%prep
%autosetup -p0 -n fox-%{version}

%build
autoreconf -fi
%configure  \
    --enable-threadsafe \
    --enable-release \
    --enable-cups \
    --with-xft \
    --with-x \
    --with-xcursor \
    --with-xrender \
    --with-xrandr \
    --with-opengl \
    --with-shape \
    --with-xshm \
    --without-profiling
make %{?_smp_mflags}

%install
%make_install
# install docu
pushd doc
doxygen -u doxygen.cfg
make docs
popd
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}/html
# FIXME: to be done via configure
if [ -d %{buildroot}%{_datadir}/doc/fox-1.6 ]; then
    mv %{buildroot}%{_datadir}/doc/fox-1.6/* %{buildroot}%{_defaultdocdir}/%{name}/html/
    rm -rf %{buildroot}%{_datadir}/doc/fox-1.6
fi
install -m644 ADDITIONS AUTHORS LICENSE* README TRACING index.html %{buildroot}%{_defaultdocdir}/%{name}/
# install desktop files for example applications
mkdir -p %{buildroot}%{_datadir}/{applications,pixmaps}
install -m 644 %{SOURCE1} %{buildroot}%{_datadir}/pixmaps/
install -m 644 %{SOURCE2} %{buildroot}%{_datadir}/pixmaps/
install -m 644 %{SOURCE3} %{buildroot}%{_datadir}/pixmaps/
install -m 644 %{SOURCE5} %{buildroot}%{_datadir}/applications/
install -m 644 %{SOURCE6} %{buildroot}%{_datadir}/applications/
install -m 644 %{SOURCE7} %{buildroot}%{_datadir}/applications/
%suse_update_desktop_file calculator
%suse_update_desktop_file pathfinder
%suse_update_desktop_file adie

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%post devel
test -f %{_bindir}/fox-config || ln -s fox16-config %{_bindir}/fox-config
test -f %{_bindir}/reswrap || ln -s reswrap16 %{_bindir}/reswrap
test -f %{_mandir}/man1/reswrap.1.gz || ln -s reswrap16.1.gz %{_mandir}/man1/reswrap.1.gz

%files doc
%doc %{_defaultdocdir}/%{name}

%files -n %{lname}
%license LICENSE*
%{_libdir}/libFOX-*.so.*
%{_libdir}/libCHART-*.so.*

%files devel
%{_bindir}/reswrap
%{_bindir}/fox-config
%{_mandir}/man1/reswrap.1%{?ext_man}
%{_includedir}/fox-*/
%{_libdir}/pkgconfig/fox.pc
%{_libdir}/libFOX-*.la
%{_libdir}/libCHART-*.la
%{_libdir}/libFOX-*.so
%{_libdir}/libCHART-*.so

%files devel-static
%{_libdir}/libFOX-*.a
%{_libdir}/libCHART-*.a

%files example-apps
%{_bindir}/Adie.stx
%{_bindir}/adie
%{_bindir}/PathFinder
%{_bindir}/calculator
%{_bindir}/shutterbug
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png
%{_mandir}/man1/adie*
%{_mandir}/man1/calculator*
%{_mandir}/man1/PathFinder*
%{_mandir}/man1/shutterbug*

%changelog
* Wed May 10 2023 Jan Engelhardt <jengelh@inai.de>
- Remove non-SUSE fragments, there is no build enabled for
  those targets anyway. Replace more -devel by pkgconfig(...).
* Sun May  7 2023 Jan Engelhardt <jengelh@inai.de>
- Replace xorg-x11-devel by pkgconfig(...)
* Wed Apr 26 2023 Jan Engelhardt <jengelh@inai.de>
- Drop require on xorg-x11-libs, that metapackage itself requires
  nothing, and does not provide any usable files either.
* Sun May  5 2019 lars@linux-schulserver.de - 1.6.57
- package license files in library package
- ran spec-cleaner
* Fri Oct  5 2018 lars@linux-schulserver.de
- Update to 1.6.57:
  + Libtool flags added on behalf of FXRuby builds and missing
    UNICODE flag added for CYGWIN32 build.
  + Problem fixed in FXString vformat().
  + Fix FXMemoryStream position() API: error code was set moving
    stream position to end of buffer.
* Thu May 18 2017 lars@linux-schulserver.de
- Update to 1.6.54:
  + Fix core dump using old GNU C Library or CYGWIN inside
    FXString::vformat.cpp.
  + Fixed typo in FXString::vformat.cpp.
* Sat Oct 22 2016 behrisch@users.sourceforge.net
- update to 1.6.52:
  + Small fixes for 64-bit casts in dctest.cpp (compiler warning issues).
  + JPEG image I/O color spaces handled better.
  + FXApp input callback message ID for SEL_IO_EXCEPT was wrong.
  + Change in how FXStat determines if a file is an executable (Windows).
* Mon Dec 15 2014 lars@linux-schulserver.de
- the -devel-static package must require the -devel-package,
  see https://en.opensuse.org/openSUSE:Packaging_guidelines#Exception
* Fri Aug 29 2014 jengelh@inai.de
- Use verifiable https://en.opensuse.org/SourceUrls and
  original tarball
- Follow shared library package naming guidelines a bit closer
* Fri Aug 15 2014 lars@linux-schulserver.de
- update to 1.6.50:
  + no upstream changes available
* Mon Sep 16 2013 lars@linux-schulserver.de
- update to 1.6.49:
  + Check index out of bounds in FXTabBook::setCurrent().
* Wed Jan 23 2013 lars@linux-schulserver.de
- update to 1.6.47:
  + Prototype of wndproc() was not correct for 64-bit Windows.
* Fri Sep 28 2012 behrisch@users.sourceforge.net
- fixed glu dependency for devel package for openSUSE > 12.2
* Wed Sep 19 2012 behrisch@users.sourceforge.net
- fixed devel dependencies for scientific linux
* Tue Sep 18 2012 idonmez@suse.com
- Add explicity glu dependency for openSUSE > 12.2
* Sun Sep  9 2012 lars@linux-schulserver.de
- create symlinks in devel package where the binaries live
  (TODO: use update-alternatives)
* Thu Jul 12 2012 lars@linux-schulserver.de
- update to 1.6.46:
  + Small tweak to FXIcon's guessthresh(), thanks to Fanglin.
  + Fixed quaternion arc() routine. In case of vectors that are
    (almost) 180 degrees apart, the wrong quaternion was returned.
  + Invalid handle issue fixed in FXWindow.
  + Backported FXPath shell escaping routine.
- added fox16-remove_date_from_reswrap.patch
  to remove date from reswrap help to support build compare
* Fri Dec  9 2011 lars@linux-schulserver.de
- update to 1.6.44:
  + removed -Wextra from CXXFLAGS
  + Force quoting in FXString FXPath::dequote and FXPath::enquote
    if the string contains at least one whitespace
* Sat Oct  1 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Mon Feb  7 2011 lars@linux-schulserver.de
- update to 1.6.43:
  + Added missing AC_FUNC_MMAP to configure.ac. Presence of mmap()
    and munmap() API's we not being discovered properly.
  + Fix libpng version 1.5. Members of png_struct are now hidden,
    so fxpngio.cpp must use newly introduced API to use
    embedded jmp_buf.
  + Fix configure.ac type which caused linkage to libGL and libGLU
    even if compiled without GL support.
* Wed Sep  1 2010 lars@linux-schulserver.de
- update to 1.6.40:
  * FXSystem::getTempDirectory() now uses TMPDIR environment
    variable if set.
  * Auto-guess icon etch mask threshold added.
  * Removed XGetDefault from code in ControlPanel.cpp.
- removed upstreamed fox-1.6.34-am111.patch
* Sun Dec 13 2009 lars@linux-schulserver.de
- update to 1.6.37:
  * Fixed remainingTimeout() returning ns, not ms remaining time.
  * Fixed bug in parsing of accelerators.
  * Fixed wrong enum value in FXComboBox.
  * Backported FXTable fix from 1.7 (delete of selected lines).
- refreshed patches, fix Obsoletes
- removed configure option --htmldir - has no effect
* Tue Jul  7 2009 coolo@novell.com
- fix build with automake 1.11
* Tue Jun 16 2009 lrupp@suse.de
- fix requires for fox16-devel on other distributions
- rename fox16-static to fox16-devel-static to follow the new
  naming policy for static libs
* Mon Apr 27 2009 behrisch@informatik.hu-berlin.de
- added libbz2-devel and cups-devel dependencies for fox-devel
* Sat Apr 11 2009 behrisch@informatik.hu-berlin.de
- update to 1.6.36:
  + Fixed FXTable startInput() issue.
  + Backported FXFont Freetype pitch size.
  + Fixed compose context create issue.
  + Bug fix in fxloadPPM() when ascii black and white bitmap is loaded.
  + Call tr() when populating color names.
  + Small bug in FXTextField when I-beam cursor surrounded by non-ascii
    UTF8 characters and it near the beginning or end of the string.
* Tue Jul 29 2008 lrupp@suse.de
- update to 1.6.34:
  + Fixed bug in FXSettings; symptoms: every once in a while,
    a key-value pair was skipped.
  + Minor tweak to order in which size constraints are being passed
    to Window Managers on X11.
    Some Window Managers had a problem with the old order.
  + Backported FXTopWindow resize() and position() fixes from 1.7.
  + Fixed GCC 4.3 warning in FXArray header file.
  + Made internal data arrays static to prevent global name
    clashes on some compilers.
  + Fixed uninitialized variable in FXFileDict.
- remove upstreamed fox-1.6.26_initialise_local_variable.patch
* Thu Apr  3 2008 lrupp@suse.de
- update to 1.6.32:
  + Fixed FXPath::simplify(). Backport from FOX 1.7.
  + Fixed Adie CPU load issue caused by clock updating.
  + Fixed FXURL::fileFromURL().
- create docs using doxygen
* Mon Dec 17 2007 lrupp@suse.de
- update to 1.6.31:
  + Bug fix to strtoull() for systems which have
    no native strtoull().
  + Missing tr() added in FXMDIClient.
  + Fix for FXRuby in FXMDIClient (don't test for message==0
    in notify message).
- split libfox%%soname to follow shared library packaging policy
- fix desktop files and add them as normal files
- enable warnings again
* Wed Oct 10 2007 lrupp@suse.de
- update to 1.6.30:
  + Fixed some issues with flush() in FXBZFileStream and
    FXGZFileStream.
  + FXDial didn't issue SEL_COMMAND when driven from keyboard.
  + Small typo found in fxfilematch() was found which affected
    character-range matching.
  + Problem in FX7Segment fixed.
  + Added ".jpeg" as additional extension for JPEG images in
    FXIconSource.
  + Fix in FXSplashWindow not killing timer if it gets destroyed
    before timer goes off.
  + FX7Segment had bug in onCmdGetStringValue() implementation
  + Cruft removed from FXMat3f.
  + Bold style fixed in FXText.
  + Read outside buffer problem fixed in FXText.
  + Bugs in FXListBox and FXTreeListBox fixed.
- added fox16-rpmlintrc
- added LICENSE_ADDENDUM, removed INSTALL from %%doc
- create desktop entries for adie, calculator and pathfinder
* Tue Jun  5 2007 lrupp@suse.de
- update to 1.6.27
  + Fixed regression in glUseFXFont() when using Xft instead of XLFD.
  + Fixed bug in FXVisual which caused drawing to FXBitmap to fail.
  + Fixed issue with bold-face text not drawing correctly in FXText
    if gap happens to be in the text-fragment being drawn.
  + FXMDIChild resize animation speed changed a little bit.
  + Decoration options interpreted under Windows-XP and UNIX as
    follows:
    DECOR_SHRINKABLE means window may be smaller, but not larger, than
    default size;
    DECOR_STRETCHABLE means window may be larger, but not smaller, than
    default size; and finally,
    DECOR_RESIZE means window may be both smaller or larger than
    default size.
- Remove libbz2 from BuildRequires (in buildsystem now)
- Remove "--with-xim": breaks keyboard support
* Thu May 10 2007 ro@suse.de
- fix typo in specfile
* Thu May  3 2007 lars@suse.de
- update to 1.6.26
- remove upstremed patches:
  + fox-1.6.20_configure_x11_extensions_header.patch
  + fox-1.6.20_AM_CFLAGS.patch
- adapt fox-1.6.26_initialise_local_variable.patch
- added Mandriva and Fedora dependencies
- require libexpat-devel for openSUSE > 10.2
* Wed Mar  7 2007 lrupp@suse.de
- fixed requires for devel package on older distributions
* Tue Mar  6 2007 lrupp@suse.de
- update to 1.6.23:
  + Fixed problem with X11 XLFD fonts. If XLFD font name specified
    directly, no font was matched.
  + Fixed spurious call to removeItem() in extractItem() inside
    FXTreeListBox.
  + Always define vfscanf(), vscanf(), and vsscanf() when on Windows.
  + Remove FXAPI in FXObjectListOf template.
* Sun Jan 28 2007 lrupp@suse.de
- add static package
- compile for release
- reorder documentation
* Fri Jan 26 2007 lrupp@suse.de
- added version numbers in provides
- build on older distributions
* Fri Dec  1 2006 lrupp@suse.de
- update to 1.6.20
  + Rolled back explicit template instantiation stuff:
    not supported everywhere.
  + Fix bug in FXMutex::locked() implementation.
  + Suppress 4244 warning (possible loss of data) on VC++ compiler.
  + Bug fix in FXApp drag and drop.
  + Wrong error message in argument check in FXTable API.
  + Fixed minor issues in FXPicker: now issues message on mouse
    button release.
  + Fixed problems in FXFile, FXSocket, FXPipe occurring on
    64-bit Windows.
* Fri Oct 13 2006 lrupp@suse.de
- update to 1.6.16
  + Fixed issue with FXMDIChild and FXTopWindow close() routine;
    this mostly affects FXRuby
  + Fixed FXTextField drawCursor() array overrun and text
    measurement bugs
  + Surround fxascii & fxunicode.cpp with namespace
  + End of stream bugs in FXGZFileStream and FXBZFileStream
  + FXToolTip & FXExpression bugs fixed
  + Updated Adie.stx
- removed fox-1.6.4_optflags.patch
* Tue Jun 13 2006 lrupp@suse.de
- fix #183748 : fox development files in run-time package
- fix #183746 : package fox is compiled without RPM_OPT_FLAGS
- fix #183739 : fox-1.6.4-3: local variable used before set
- reduce BuildRequires
- enable configure options: cups,xft,xim,xcursor,xrandr,opengl,shape,xshm
* Wed Apr 26 2006 lrupp@suse.de
- new source 1.6.4 from upstream - package is alive again ;-)
* Mon Jun 23 2003 pthomas@suse.de
- Include accidently left out libFOX.so.
* Fri Jun 20 2003 pthomas@suse.de
- Initial package creation.
- Use AM_CXXFLAGS instead of overriding CXXFLAGS.
- Clean up code, including int->pointer casts.
